package Acme::MetaSyntactic::antlers;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::antlers - The antler theme

=head1 DESCRIPTION

Kinds of moose and other antlered, er, moose.

=head1 CONTRIBUTOR

Gaal Yahas.

Introduced in version 0.46, published on October 31, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
moose elk caribou wapiti alces_alces deer hirvi eland oryx antler
velvet_antler
