package Acme::MetaSyntactic::flintstones;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::flintstones - The Flintstones theme

=head1 DESCRIPTION

The characters from the popular serial.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in version 0.01, published on January 14, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
fred wilma pebbles dino barney betty bammbamm hoppy 
