package Acme::MetaSyntactic::barbarella;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::barbarella - Characters from the movie.

=head1 DESCRIPTION

According to L<http://www.hollywoodcomics.com/forestbbd.html>, 
Jean-Claude Forest created the character of Barbarella for I<V-Magazine>
in 1962. Barbarella was an immediate runaway bestseller and was soon
translated in a dozen countries. Not long after, it was adapted into
a major motion picture, starring Jane Fonda, for which Forest acted as
design consultant.

This theme lists the main characters from the 1968 movie, I<Barbarella>,
starring Jane Fonda.

The list is taken from L<http://www.imdb.com/title/tt0062711/fullcredits>.

=head1 CONTRIBUTOR

Abigail

Introduced in version 0.57, published on January 16, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>,

=cut

__DATA__
# names
Barbarella Pygar The_Great_Tyrant Durand_Durand Professor_Ping
President_of_Earth Captain_Moon Captain_Sun Stomoxys Glossina
Dildano Mark_Hand
