package Acme::MetaSyntactic::magicroundabout;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::magicroundabout - The Magic Round-About theme

=head1 DESCRIPTION

Characters from the Magic Round About children television series.

=head1 CONTRIBUTOR

Cédric Bouvier, C<< <cbouvi@cpan.org> >>.

Introduced in version 0.24, published on May 30, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en

# names fr
Ambroise
Azalee
Flappy
Margotte
Pollux
Zebulon

# names en
Brian
Dougal
Dylan
Ermintrude
Florence
Zebedee

