package Acme::MetaSyntactic::scooby_doo;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::scooby_doo - The Scooby Doo theme

=head1 DESCRIPTION

Characters from the Scooby-Doo serial.

=head1 CONTRIBUTOR

Michel Rodriguez

Introduced in version 0.78, published on June 12, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en
# names en
Scooby_Doo Shaggy Daphne Velma Freddy Scrappy_Doo Scooby_Dum   Scooby_Dee
# names fr
Scooby_Doo Sammy Daphne  Vera  Fred   Scrappy_Doo Oncle_Scooby

