package Acme::MetaSyntactic::dwarves;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::dwarves - The seven dwarves theme

=head1 DESCRIPTION

Snow-White seven dwarves.

=head1 CONTRIBUTORS

Antoine Hulin (January 2005).
Proposed again by Abigail (October 2005).
Proposed yet again by Xavier Caron (October 2005).

I definitely I<had> to include this list! C<:-)>

Introduced in version 0.48, published on November 14, 2005.

Updated by Abigail (added Danish, German, Spanish, Finnish, Hungarian,
Italian, Norwegian, Portuguese and Swedish) in version 0.74, published
on May 15, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en
# names da
Brille     Lystig      Gnavpot     Dumpe       Sovnig      Prosit      Flovmand
# names de
Chef       Happy       Brummbar    Seppl       Schlafmutz  Hatschi     Pimpel
# names en
Doc        Happy       Grumpy      Dopey       Sleepy      Sneezy      Bashfull
# names es
Sabio      Feliz       Grunon      Tontin      Dormilon    Alergico    Romantico
# names fi
Viisas     Lystikas    Joro        Vilkas      Unelias     Nuhanena    Ujo
# names fr
Prof       Joyeux      Grincheux   Simplet     Dormeur     Atchoum     Timide
# names hu
Tudor      Vidor       Morgo       Kuka        Szundi      Hapci       Szende
# names it
Dotto      Gongolo     Brontolo    Cucciolo    Pisolo      Eolo        Mammolo
# names no
Brille     Lystig      Sinnataggen Minsten     Sovnig      Prosit      Blygen
# names pt
Mestre     Feliz       Zangado     Dunga       Soneca      Atchim      Dengoso
# names sv
Kloker     Glader      Butter      Toker       Trotter     Prosit      Blyger
