package Acme::MetaSyntactic::python;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::python - The Python theme

=head1 DESCRIPTION

The Pythonesque variable names used in Python examples.

=head1 CONTRIBUTOR

Ricardo Signes.

Introduced in version 0.15, published on March 28, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
spam        eggs      ham         toast
beans       bacon     sausage     tomato
lobster     shallots  aubergine   truffle
pate        shrubbery herring     blancmange
