package Acme::MetaSyntactic::peanuts;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::peanuts - The Peanuts theme

=head1 DESCRIPTION

The characters form the world famous Peanuts comic strip,
drawn by Charles M. Schulz and published from October 2, 1950
to January 3, 2000.

The official Peanuts website is at L<http://www.snoopy.com/>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in version 0.34, published on August 8, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Snoopy
Charlie_Brown
Woodstock
Linus
Lucy
Sally
Schroeder
Peppermint_Patty
Marcie
Pigpen
Franklin
Rerun
