package Acme::MetaSyntactic::colors;
use Acme::MetaSyntactic::Alias;
our @ISA = qw( Acme::MetaSyntactic::Alias );
__PACKAGE__->init('colours');
1;

=head1 NAME

Acme::MetaSyntactic::colors - The colors theme
    
=head1 DESCRIPTION
    
This theme is just an alias of the C<colours> theme, to please the
speakers of the various dialects of English. C<;-)>

=head1 CONTRIBUTOR

Philippe Bruhat

Introduced in version 0.77, published on June 5, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Alias>,
L<Acme::MetaSyntactic::colours>.

=cut
    
# no __DATA__ section required!

