package Acme::MetaSyntactic::groo;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::groo - The Groo the Wanderer theme

=head1 DESCRIPTION

A list of characters from the I<Groo the Wanderer> long-running
comic-book authored by Sergio Aragonès and Mark Evanier.

If you are interested in Groo, you should have a look at
L<http://www.groo.com/>, L<http://www.povonline.com/> and
L<http://www.sergioaragones.com/>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in version 0.27, published on June 21, 2005.

Corrected a typo in version 0.82, published on July 10, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Groo Rufferto Sage Chakaal Minstrel Grooella Arba Dakarba Arcadio
Taranto Pal Drumm Mulch Scribe Weaver Gravito Granny_Groo Pipil_Khan
The_Witch_of_Kaan Captain_Ahax
