package Acme::MetaSyntactic::metro;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::metro - The metro theme

=head1 DESCRIPTION

This theme lists all the active stations of the Paris subway.

=head1 CONTRIBUTOR

Philippe 'BooK' Bruhat

Introduced in version 0.83, published on July 17, 2006.

=head1 DEDICATION

This module is dedicated to the Paris subway, which was opened to the
public 106 years ago, on July 19, 1900.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Abbesses
Alesia
Alexandre_Dumas
Alma_Marceau
Anatole_France
Anvers
Argentine
Arts_et_Metiers
Assemblee_Nationale
Aubervilliers_Pantin_Quatre_Chemins
Avenue_Emile_Zola
Avron
Balard
Barbes_Rochechouart
Basilique_de_Saint_Denis
Bastille
Bel_Air
Belleville
Berault
Bercy
Bibliotheque_Francois_Mitterrand
Billancourt
Bir_Hakeim
Blanche
Bobigny_Pablo_Picasso
Bobigny_Pantin_Raymond_Queneau
Boissiere
Bolivar
Bonne_Nouvelle
Botzaris
Boucicaut
Boulogne_Jean_Jaures
Boulogne_Pont_de_Saint_Cloud
Bourse
Breguet_Sabin
Brochant
Buttes_Chaumont
Buzenval
Cadet
Cambronne
Campo_Formio
Cardinal_Lemoine
Carrefour_Pleyel
Censier_Daubenton
Champs_Elysees_Clemenceau
Chardon_Lagache
Charenton_Ecoles
Charles_de_Gaulle_Etoile
Charles_Michels
Charonne
Chateau_d_Eau
Chateau_de_Vincennes
Chateau_Landon
Chateau_Rouge
Chatelet
Chatillon_Montrouge
Chaussee_d_Antin_La_Fayette
Chemin_Vert
Chevaleret
Cite
Cluny_la_Sorbonne
Colonel_Fabien
Commerce
Concorde
Convention
Corentin_Cariou
Corentin_Celton
Corvisart
Courcelles
Couronnes
Cour_Saint_Emilion
Creteil_l_Echat
Creteil_Prefecture
Creteil_Universite
Crimee
Croix_de_Chavaux
Daumesnil
Denfert_Rochereau
Dugommier
Dupleix
Duroc
Ecole_Militaire
Ecole_Veterinaire_de_Maisons_Alfort
Edgar_Quinet
Eglise_d_Auteuil
Eglise_de_Pantin
Esplanade_de_la_Defense
Etienne_Marcel
Europe
Exelmans
Faidherbe_Chaligny
Falguiere
Felix_Faure
Filles_du_Calvaire
Fort_d_Aubervilliers
Franklin_D_Roosevelt
Gabriel_Peri_Asnieres_Gennevilliers
Gaite
Gallieni
Gambetta
Gare_d_Austerlitz
Gare_de_l_Est
Gare_de_Lyon
Gare_du_Nord
Garibaldi
George_V
Glaciere
Goncourt
Grands_Boulevards
Guy_Moquet
Havre_Caumartin
Hoche
Hotel_de_ville
Hotel_de_Ville
Iena
Invalides
Jacques_Bonsergent
Jasmin
Jaures
Javel_Andre_Citroen
Jourdain
Jules_Joffrin
Jussieu
Kleber
La_Chapelle
La_Courneuve_8_Mai_1945
La_Defense_Grande_Arche
La_Fourche
Lamarck_Caulaincourt
La_Motte_Picquet_Grenelle
La_Muette
La_Tour_Maubourg
Laumiere
Ledru_Rollin
Le_Kremlin_Bicetre
Le_Peletier
Les_Gobelins
Les_Halles
Les_Sablons
Liberte
Liege
Louis_Blanc
Louise_Michel
Lourmel
Louvre_Rivoli
Mabillon
Madeleine
Mairie_de_Clichy
Mairie_de_Montreuil
Mairie_de_Saint_Ouen
Mairie_des_Lilas
Mairie_d_Issy
Mairie_d_Ivry
Maison_Blanche
Maisons_Alfort_Les_Juilliottes
Maisons_Alfort_Stade
Malakoff_Plateau_de_Vanves
Malakoff_Rue_Etienne_Dolet
Malsherbes
Maraichers
Marcadet_Poissonniers
Marcel_Sembat
Marx_Dormoy
Maubert_Mutualite
Menilmontant
Michel_Ange_Auteuil
Michel_Ange_Molitor
Michel_Bizot
Mirabeau
Miromesnil
Monceau
Montgallet
Montparnasse_Bienvenue
Mouton_Duvernet
Nation
Nationale
Notre_Dame_de_Lorette
Notre_Dame_des_Champs
Oberkampf
Odeon
Opera
Ourcq
Palais_Royal_Musee_du_Louvre
Parmentier
Passy
Pasteur
Pelleport
Pereire
Pere_Lachaise
Pernety
Philippe_Auguste
Picpus
Pierre_Curie
Pigalle
Place_de_Clichy
Place_des_Fetes
Place_d_Italie
Place_Monge
Plaisance
Poissonniere
Pont_de_Levallois_Becon
Pont_de_Neuilly
Pont_de_Sevres
Pont_Marie
Pont_Neuf
Porte_Dauphine
Porte_d_Auteuil
Porte_de_Bagnolet
Porte_de_Champerret
Porte_de_Charenton
Porte_de_Choisy
Porte_de_Clichy
Porte_de_Clignancourt
Porte_de_la_Chapelle
Porte_de_la_Villette
Porte_de_Montreuil
Porte_de_Pantin
Porte_de_Saint_Cloud
Porte_de_Saint_Ouen
Porte_des_Lilas
Porte_de_Vanves
Porte_de_Versailles
Porte_de_Vincennes
Porte_d_Italie
Porte_d_Ivry
Porte_Doree
Porte_d_Orleans
Porte_Maillot
Pre_Saint_Gervais
Pyramides
Pyrenees
Quai_de_la_Gare
Quai_de_la_Rapee
Quatre_Septembre
Rambuteau
Ranelagh
Raspail
Reaumur_Sebastopol
Rennes
Republique
Reuilly_Diderot
Richard_Lenoir
Richelieu_Drouot
Riquet
Robespierre
Rome
Rue_de_la_Pompe
Rue_des_Boulets
Rue_du_Bac
Rue_Saint_Maur
Saint_Ambroise
Saint_Augustin
Saint_Denis_Porte_de_Paris
Saint_Denis_Universite
Saint_Fargeau
Saint_Francois_Xavier
Saint_Georges
Saint_Germain_des_Pres
Saint_Jacques
Saint_Lazare
Saint_Mande
Saint_Marcel
Saint_Michel
Saint_Paul
Saint_Philippe_du_Roule
Saint_Placide
Saint_Sebastien_Froissart
Saint_Sulpice
Segur
Sentier
Sevres_Babylone
Sevres_Lecourbe
Simplon
Solferino
Stalingrad
Strasbourg_Saint_Denis
Sully_Morland
Telegraphe
Temple
Ternes
Tolbiac
Trinite_d_Estienne_d_Orves
Trocadero
Tuileries
Vaneau
Varenne
Vaugirard
Vavin
Victor_Hugo
Villejuif_Leo_Lagrange
Villejuif_Louis_Aragon
Villejuif_Paul_Vaillant_Couturier
Villiers
Volontaires
Voltaire
Wagram
