package Acme::MetaSyntactic::jerkcity;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::jerkcity - The Jerkcity theme

=head1 DESCRIPTION

Character names and other keywords from the popular (at least
on #perl) webcomic I<jerkcity>.

See L<http://www.jerkcity.com/> for details.

=head1 CONTRIBUTOR

Rafael Garcia-Suarez.

Introduced in version 0.37, published on August 29, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Atandt Bung Deuce Dick Effigy Hanford Harriet Jean_Charles Net Ozone
Pants Rands Spigot T HUGLAGHALGHALGHAL gay dicks dongs rape piss

