package Acme::MetaSyntactic::trigan;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::trigan - The I<The Trigan Empire> theme

=head1 DESCRIPTION

Characters from the British comic I<The Trigan Empire>, written
mainly by Mike Butterworth with beautiful artwork by I<Don Lawrence>.
The comic ran from 1965 till 1982.

Learn all about it on L<http://www.trigan.com/>.

=head1 CONTRIBUTOR

Abigail

Introduced in version 0.64, published on March 6, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Trigo Brag Klud Peric Janno Keren Roffa Salvia Kassar Ursa Argo Rilla Nikka
