package Acme::MetaSyntactic::barbapapa;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::barbapapa - The Barbapapa theme

=head1 DESCRIPTION

The Barbapapa family consists of 9 members, 7 children and 2 adults.
This cartoon series was created by French architect Annette Tison and
her American husband Talus Taylor in 1970. First as comic books, and
later as a television series.

The official Barbapapa web site is at L<http://www.barbapapa.fr/>.

=head1 CONTRIBUTOR

Abigail

Introduced in version 0.54, published on December 26, 2005.

=head1 DEDICATION

Philippe dedicates this module to his niece Enora. Merry Christmas!

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
fr
# names fr
Barbapapa Barbamama Barbabelle Barbalala Barbibul Barbidou Barbidur
Barbotine Barbouille
# names en
Barbapapa Barbamama Barbabravo Barbabright Barbazoo Barbabeau Barbabelle
Barbalala Barbalib
# names nl
Barbapapa Barbamama Barbabenno Barbabella Barbabientje Barbaborre
Barbabob Barbabee Barbalala
# names de
Barbapapa Barbamama Barbabella Barbaletta Barbarix Barbawum Barbabo
Barbakus Barbalala
# names fi
Barbapapa Barbamama Barbabravo Barbalib Barbazoo Barbabelle Barbalala
Barbabright Barbabeau
# names pl
Barbapapa Barbamama Barbabelle Barbalala Barbibul Barbidou Barbidur
Barbotine Barbouille
# names sv
Barbapapa Barbamama Barbazoo Barbalala Barbabok Barbaskon Barbafin
Barbaflink Barbastark
