package Acme::MetaSyntactic::pantagruel;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pantagruel - The Pantagruel theme

=head1 DESCRIPTION

Pantagruel's genealogy.

List taken from I<Pantagruel>, chapter 2, by Maistre Françoys Rabelais.

=head1 CONTRIBUTOR

Rafael Garcia-Suarez

Introduced in version 0.72, published on May 1, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Chalbroth
Sarabroth
Faribroth
Hurtaly
Nembroth
Athlas
Goliath
Eryx
Titius
Eryon
Polyphemus
Cacus
Etion
Enceladus
Ceus
Typhoeus
Aloeus
Othus
Aegeon
Briareus
Porphyrio
Adamastor
Anteus
Agatho
Porus
Aranthas
Gabbara
Goliath_de_Secundille
Offot
Artachees
Oromedon
Gemmagog
Sisyphus
Hercules
Enay
Fierabras
Morguan
Fracassus
Ferragus
Happemousche
Bolivorax
Longys
Gayoffe
Maschefain
Brulefer
Engoulevent
Galehaut
Myrelangault
Galaffre
Falourdin
Roboastre
Sortibrant_de_Conimbres
Brushant_de_Mommiere
Bruyer
Mabrun
Foutasnon
Hacquelebac
Vitdegrain
Grantgousier
Gargantua
Pantagruel
