package Acme::MetaSyntactic::pynchon;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pynchon - The Pynchon theme

=head1 DESCRIPTION

Character names from Thomas Pynchon's books.

David Landgren not only named all the machines in the C<mongueurs.net>
domain (C<stencil>, C<sferics> and C<profane>) after characters from
Thomas Pynchon's books, but also provided a first list.

The pynchon list will probably grow in future versions, as David goes
through his books.

=head1 CONTRIBUTOR

David Landgren.

Introduced in version 0.03, published on January 14, 2005.

Updated by David Landgren in version 0.41, published on September 26, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
porpentine slothrop stencil profane godolphin yoyodyne waste
sferics oedipa mondaugen eigenvalue schlozhauer schoenmaker
bongo_shaftsbury maijstral achtfaden sachsa mantissa angevine
anthroresearch apocheir aquilina barkhausen basilisco bergomask beukes
bodine boeblich bondelschwaartz borracho carruthers_pillow chiclitz chobb
contango covess delgado dnubietna dupiro echerze eckstine fairing falange
fauchard fazzo fenice flake fleische foppl gadrulfi gascoigne gebrail
gerfaut geronimo girgis gland gonzi goodfellow gottschalk groomsman
halidom katz khevenhuller_metsch kholsky knoop lazar lepsius leutwein
lowenstein manganese mannaro
