package Acme::MetaSyntactic::buffy;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::buffy - The Buffy theme

=head1 DESCRIPTION

The characters from London.pm's favorite serial.
Courtesy of L<http://buffyology.johnhorner.nu/>.

=head1 CONTRIBUTOR

Rafael Garcia-Suarez.

Introduced in version 0.09, published on February 7, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Adam Angel Anya Buffy Cordelia Darla Dawn Drusilla Faith Giles Glory
Jenny Jonathan Joyce Kendra Oz Snyder Prof_Walsh Riley Spike Tara
The_Master The_Mayor Warren Wesley Willow Xander
