package Acme::MetaSyntactic::teletubbies;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::teletubbies - The teletubbies theme

=head1 DESCRIPTION

Over the hills and far away, Teletubbies come to play.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in version 0.23, published on May 23, 2005.

=head1 ACKNOWLEDGMENT

Thanks to Jérôme Fenal, for inspiration over IRC.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Tinky_Winky Dipsy Laa_Laa Po
Noo_Noo Trumpets Baby_Sun Narrator
