package Acme::MetaSyntactic::contrade;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::contrade - The contrade theme

=head1 DESCRIPTION

The most well-known contrade (districts within an Italian city) are
probably the 17 that race in the Palio di Siena.

=head1 CONTRIBUTOR

Estelle Souche

Introduced in version 0.65, published on March 13, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Aquila 
Bruco 
Chiocciola 
Civetta 
Drago 
Giraffa 
Istrice 
Leocorno 
Lupa 
Nicchio 
Oca 
Onda 
Pantera 
Selva 
Tartuca 
Torre 
Valdimontone 
