package Acme::MetaSyntactic::pie;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pie - The pie theme

=head1 DESCRIPTION

A list of English pies.

"Isle of Skye" is, apparently cockney rhyming slang for pie.

=head1 CONTRIBUTOR

Nicholas Clark

Introduced in version 0.86, published on August 7, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
apple
cherry
mince
steak_and_kidney
chicken_and_mushroom
beef_and_ale
pumpkin
lemon_merengue
pecan
Isle_of_Skye
