package Acme::MetaSyntactic::userfriendly;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::userfriendly - The I<User Friendly> theme

=head1 DESCRIPTION

Characters from the web comic I<User Friendly>. The daily comic first
appeared on November 17, 1997, and is drawn by Illiad.

Read it at L<http://www.userfriendly.org/>.

=head1 CONTRIBUTOR

Abigail

Introduced in version 0.74, published on May 15, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
A_J The_Chief Dust_Puppy Erwin Greg Mike Miranda Pitr Sid Smiling_Man Stef
Artur BSD_Daemon Clippy Cobb Mr_Cola Crud_Puppy Cthulhu Hillary Matt
Pearl Tanya Tux
