package Acme::MetaSyntactic::discworld;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::discworld - The Discworld theme

=head1 DESCRIPTION

This theme contains items from Terry Pratchett's Discworld series.

=head1 CONTRIBUTOR

Martin Vorländer.

Introduced in version 0.42, published on October 3, 2005.

Updated by Jean Forget in version 0.47, published on November 7, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
great_a_tuin berilia jerakeen tubul great_t_phon
rincewind twoflower death nanny_ogg granny_weatherwax magrat_garlick
agnes_nitt king_verence jason_ogg shawn_ogg
mustrum_ridcully ponder_stibbons windle_poons ipslore igneous_cutwell
eric mort ysabell susan binky
alberto_malich lord_vetinari leonardo_da_quirm lady_sybil_ramkin
greebo pteppic ptraci 
captain_vimes carrot angua littlebottom
detritus sergeant_colon nobby reg_shoe errol gaspode bel_shamharoth
offler blind_io creosote conina nijel koomi ksandra granpone bravd weasel tethis
bathys garhartra dibbler gaffer silverfish
brutha vorbis casanunda william_de_worde
cohen caleb_the_ripper old_vincent mad_hamish boy_willy

ankh_morpork the_broken_drum dunmanifestin wyrmberg nef sto_lat lancre
cori_celesti tsort pseudopolis sto_helit klatch quirm
ramtops uberwald djelibeybi ephebe genua llamedos agatean_empire xxxx

