package Acme::MetaSyntactic::stars;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::stars - The stars theme

=head1 DESCRIPTION

A list of traditional star names, as listed on
L<http://en.wikipedia.org/wiki/List_of_traditional_star_names>.

=head1 CONTRIBUTOR

Rafael Garcia-Suarez.

Introduced in version 0.39, published on September 12, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Acamar Achernar Acrux Acubens Adhafera Adhara Agena Albali Albireo Alcor
Alcyone Aldebaran Alderamin Alfirk Algedi Algenib Algieba Algol Algorab
Alhena Alioth Alkaid Alkalurops Alkes Almach Alnilam Alnitak Alphard
Alphecca Alpheratz Alshain Altair Altais Alterf Aludra Alula_Australis
Alula_Borealis Alya Ancha Ankaa Antares Arcturus Arkab Arneb Ascella
Aspidiske Asterope Atik Atlas Atria Avior Azha Baten_Kaitos Becrux Beid
Bellatrix Benetnasch Betelgeuse Canopus Capella Caph Castor Celaeno Chara
Cheleb Chertan Chort Cursa Dabih Deneb Deneb_Algedi Deneb_Kaitos Denebola
Diphda Dnoces Dschubba Dubhe Edasich Electra Elnath Eltanin Enif Errai
Fomalhaut Furud Gacrux Gomeisa Graffias Grumium Hadar Hamal Homam Izar
Kaus_Australis Kaus_Borealis Kaus_Media Keid Kitalpha Kochab Kornephoros
Lesath Maia Marfik Markab Matar Mebsuta Media Megrez Meissa Mekbuda
Menkab Menkalinan Menkar Menkent Merak Merope Mesarthim Miaplacidus Mimosa
Mintaka Mira Mirach Mirfak Mirzam Mizar Mothallah Muhlifain Muscida Naos
Nashira Navi Nekkar Nihal Nunki Nusakan Peacock Phact Phad Phecda Pherkad
Pleione Polaris Pollux Porrima Procyon Propus Pulcherrima Rasalgethi
Rasalhague Rastaban Regor Rigel Rigil_Kentaurus Rotanev Ruchba Ruchbah
Rukbat Sabik Sadalbari Sadalmelik Sadalsuud Sadatoni Sadr Saiph Sargas
Scheat Schedar Seginus Shaula Sheliak Sheratan Sirius Situla Skat Spica
Sualocin Suhail Sulafat Syrma Talitha Tania_Australis Tania_Borealis
Tarazed Taygeta Tegmine Thuban Unukalhai Vega Vindemiatrix Wasat Wezen
Yed_Posterior Yed_Prior Yildun Zaniah Zaurak Zavijava Zubenelakrab
Zubenelgenubi Zubeneschamali
