package Acme::MetaSyntactic::hhgg;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::hhgg - The Hitch Hiker's Guide to the Galaxy theme

=head1 DESCRIPTION

Characters and other names from Douglas Adams's "Hitch Hiker's Guide to
the Galaxy" book series.

The list is very incomplete (it should contain at least 42 items).

After glancing at
L<http://en.wikisource.org/wiki/The_Ultra-Complete_Index_to_the_Hitch_Hiker%27s_Guide_to_the_Galaxy>,
I wonder if I should include all the entries...

=head1 CONTRIBUTOR

Aldo Calpini.

Introduced in version 0.11, published on February 28, 2005.

Updated by Philippe "BooK" Bruhat in version 0.14, published on March 21, 2005.

Link to I<The Ultra-Complete Index to the Hitch Hiker's Guide to the Galaxy>
(written and entirely copyrighted 1992-94 by Mathias Maul)
entry on wikipedia provided by Jean Forget in time for version 0.28,
published on June 27, 2005. Link updated for version 0.69, published
on April 10, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
answer arthur babelfish beeblebrox bugblatter_beast eccentrica_gallumbits 
fenchurch ford heartofgold jeltz kwaltz magrathea marvin milliways 
pan_galactic_gargle_blaster slartibartfast trillian vogon wonko zaphod
fortytwo
